@@ -20,11 +20,13 @@ class Measurement(metaclass=MetaMeasurement):
         for attribute in kwargs:
             if self.accept_dynamic_fields and not hasattr(self, attribute):
                 cls = Field
+                _type = None
                 self.columns += [attribute]
+                self.fields += [attribute]
             else:
                 cls = type(getattr(self, attribute))
-            _type = getattr(self, attribute)._type
+                _type = getattr(self, attribute)._type
             setattr(self, attribute, cls(name=attribute, value=kwargs[attribute], _type=_type))
 
     def get_values(self):
-        return {column: getattr(getattr(self, column), 'value') for column in self.columns}
+        return {column: getattr(getattr(self, column), 'value') for column in self.columns if hasattr(self, column)}
